import { NotFoundPage } from "nextra-theme-docs";

<div className="text-center py-20">

# 404: Page Not Found

The page you were looking for does not exist.

<div className="text-md">
  <NotFoundPage className="text-left" />
</div>

</div>